@@ -1,10 +1,13 @@
+from typing import Optional, Tuple
+
+import torch
 from torch import nn
 
-from labml_helpers.module import Module
 from labml_nn.lstm import LSTM
+from python_autocomplete.models import AutoregressiveModel
 
 
-class LstmModel(Module):
+class LstmModel(AutoregressiveModel):
     def __init__(self, *,
                  n_tokens: int,
                  embedding_size: int,
@@ -18,10 +21,9 @@ class LstmModel(Module):
                          n_layers=n_layers)
         self.fc = nn.Linear(hidden_size, n_tokens)
 
-    def __call__(self, x, h0=None, c0=None):
+    def __call__(self, x: torch.Tensor, state: Optional[Tuple[torch.Tensor, torch.Tensor]]):
         # shape of x is [seq, batch, feat]
         x = self.embedding(x)
-        state = (h0, c0) if h0 is not None else None
         out, (hn, cn) = self.lstm(x, state)
         logits = self.fc(out)
 
